@@ -84,33 +84,68 @@ class BaseQuestion(object):
     def text(self):
         return self._text_xpb.get_text_(self._question_element).strip()
 
-    _answer_xpb = xpb.span.attribute_contains('id', 'answer_target')
-
     def __repr__(self):
         return '<Question: {0}>'.format(self.text)
 
 
-
 class Question(BaseQuestion):
 
+    def return_none_if_broken(function):
+        def wrapped(self):
+            if self.answered:
+                return function(self)
+        return wrapped
+
+    _answers_xpb = xpb.div.with_class('answers').\
+                   p.with_class('answer')
+
+    def __init__(self, question_element):
+        super(Question, self).__init__(question_element)
+        try:
+            self._their_answer_span, self._my_answer_span = \
+            self._answers_xpb.span.with_class('text').apply_(self._question_element)
+            self._their_note_span, self._my_note_span = \
+            self._answers_xpb.span.with_class('note').apply_(self._question_element)
+        except:
+            pass
+
     @util.cached_property
-    def answer(self):
-        if self.answered:
-            return self._answer_xpb.get_text_(self._question_element).strip()
+    @return_none_if_broken
+    def their_answer(self):
+        return self._their_answer_span.text_content().strip()
+
+    @util.cached_property
+    @return_none_if_broken
+    def my_answer(self):
+        return self._my_answer_span.text_content().strip()
+
+    @util.cached_property
+    @return_none_if_broken
+    def their_answer_matches(self):
+        return 'not_accepted' not in self._their_answer_span.attrib['class']
+
+    @util.cached_property
+    @return_none_if_broken
+    def my_answer_matches(self):
+        return 'not_accepted' not in self._my_answer_span.attrib['class']
+
+    @util.cached_property
+    @return_none_if_broken
+    def their_note(self):
+        return self._their_note_span.text_content().strip()
+
+    @util.cached_property
+    @return_none_if_broken
+    def my_note(self):
+        return self._my_note_span.text_content().strip()
 
     _explanation_xpb = xpb.div.span.with_class('note')
 
-    @util.cached_property
-    def explanation(self):
-        if self.answered:
-            return self._explanation_xpb.get_text_(
-                self._question_element
-            ).strip()
-
 
 class UserQuestion(BaseQuestion):
 
     _answer_option_xpb = xpb.ul.with_class('self_answers').li
+    _explanation_xpb = xpb.div.with_class('your_explanation').p.with_class('value')
 
     @util.cached_property
     def answer_options(self):
@@ -121,6 +156,17 @@ class UserQuestion(BaseQuestion):
             )
         ]
 
+    @util.cached_property
+    def explanation(self):
+        try:
+            return self._explanation_xpb.get_text_(self._question_element)
+        except:
+            pass
+
+    @util.cached_property
+    def answer_text_to_option(self):
+        return {option.text: option for option in self.answer_options}
+
 
 class AnswerOption(object):
 
@@ -136,8 +182,8 @@ class AnswerOption(object):
         return 'match' in self._element.attrib['class']
 
     @util.cached_property
-    def answer_text(self):
-        return self._element.text_content()
+    def text(self):
+        return self._element.text_content().strip()
 
     @util.cached_property
     def id(self):
@@ -186,20 +232,21 @@ class Questions(object):
         'not_important': 5
     }
 
-    _uri = 'questions/ask'
+    path = 'questions/ask'
 
     def __init__(self, session, importances=importances, user_id=None):
+        self.importance_name_to_fetchable = {}
         for importance in importances:
             fetchable = util.Fetchable(util.FetchMarshall(
                 QuestionHTMLFetcher(session, 'questions', **{importance: 1}),
                 QuestionProcessor(UserQuestion)
             ))
+            self.importance_name_to_fetchable[importance] = fetchable
             setattr(self, importance, fetchable)
         self._session = session
         if user_id:
             self._user_id = user_id
 
-
     @util.cached_property
     def _user_id(self):
         return self._session.get_current_user_profile().id
@@ -214,7 +261,14 @@ class Questions(object):
         if len(match_response_ids) == len(user_question.answer_options):
             match_response_ids = 'irrelevant'
         return self.respond(user_question.id, user_response_ids, match_response_ids,
-                     importance)
+                            importance, note=user_question.explanation or '')
+
+    def respond_from_question(self, question, question_id_to_user_question,
+                              importance, switch_acceptable_answer=False):
+        user_question = question_id_to_user_question.get(question.id, None)
+        if not user_question: return
+        option_index = user_question.answer_text_to_option[question.their_answer].id
+        self.respond(question.id, [option_index], [option_index], importance)
 
     def respond(self, question_id, user_response_ids, match_response_ids,
                 importance, note='', is_public=1, is_new=1):
@@ -226,16 +280,19 @@ class Questions(object):
             'show_all': 0,
             'targetid': self._user_id,
             'qid': question_id,
-            'is_new': is_new,
             'answers': user_response_ids,
             'matchanswers': match_response_ids,
+            'is_new': is_new,
             'is_public': is_public,
             'note': note,
             'importance': importance,
             'delete_note': 0
         }
-        log.debug(form_data)
         return self._session.okc_post(
-            self._uri, data=form_data, headers=self.headers, allow_redirects=False,
-            params=form_data
+            self.path, data=form_data, headers=self.headers
+        )
+
+    def clear(self):
+        return self._session.okc_post(
+            'questions', data={'clear_all': 1}, headers=self.headers
         )
